diff --git a/webapp/web/css/developer/developerPanel.css b/webapp/web/css/developer/developerPanel.css
index ae61e5401..b93ca7288 100644
--- a/webapp/web/css/developer/developerPanel.css
+++ b/webapp/web/css/developer/developerPanel.css
@@ -46,3 +46,28 @@ div.developer input[type="text"]:disabled {
div.developer a {
margin: 3px;
}
+
+#developerPanelBody ul.ui-tabs-nav li a {
+ padding: 0em 1em;
+}
+
+#developerPanelBody .ui-widget-header {
+ background-image: none;
+ background-color: #CC9900;
+}
+
+#developerPanelBody .ui-widget-content {
+ background-image: none;
+ background-color: #f7dd8a;
+}
+
+#developerPanelBody .ui-widget-header .ui-state-default {
+ background-image: none;
+ background-color: #f7cc33;
+}
+
+#developerPanelBody .ui-widget-header li.ui-state-active {
+ background-image: none;
+ background-color: #f7dd8a;
+}
+
diff --git a/webapp/web/templates/freemarker/page/partials/developer.ftl b/webapp/web/templates/freemarker/page/partials/developer.ftl
index 115718197..efc60beee 100644
--- a/webapp/web/templates/freemarker/page/partials/developer.ftl
+++ b/webapp/web/templates/freemarker/page/partials/developer.ftl
@@ -1,6 +1,9 @@
<#-- $This file is distributed under the terms of the license in /doc/license.txt$ -->
-
+
${scripts.add('')}
-
\ No newline at end of file
+${scripts.add('')}
diff --git a/webapp/web/templates/freemarker/page/partials/developerPanel.ftl b/webapp/web/templates/freemarker/page/partials/developerPanel.ftl
index 2528912cc..013d15973 100644
--- a/webapp/web/templates/freemarker/page/partials/developerPanel.ftl
+++ b/webapp/web/templates/freemarker/page/partials/developerPanel.ftl
@@ -31,75 +31,89 @@
-
-
- Page configuration
-
- <@showCheckbox "developer_pageContents_logCustomListView" />
- Log the use of custom list view XML files.
-
-
- <@showCheckbox "developer_pageContents_logCustomShortView" />
- Log the use of custom short views in search, index and browse pages.
-
-
-
-
- Language support
-
- <@showCheckbox "developer_i18n_defeatCache" />
- Defeat the cache of language property files
-
-
- <@showCheckbox "developer_i18n_logStringRequests" />
- Log the retrieval of language strings
-
-
-
-
-
-
-
-
- Freemarker templates
-
- <@showCheckbox "developer_defeatFreemarkerCache" />
- Defeat the template cache
-
-
- <@showCheckbox "developer_insertFreemarkerDelimiters" />
- Insert HTML comments at start and end of templates
-
-
-
-
- SPARQL Queries
-
- <@showCheckbox "developer_loggingRDFService_enable" />
- Log each query
-
-
-
- <@showCheckbox "developer_loggingRDFService_stackTrace" />
- Add stack trace
-
-
- Restrict by query string
- <@showTextbox "developer_loggingRDFService_queryRestriction" />
-
-
- Restrict by calling stack
- <@showTextbox "developer_loggingRDFService_stackRestriction" />
-
+
+
+
+
+
+
+ Page configuration
+
+ <@showCheckbox "developer_pageContents_logCustomListView" />
+ Log the use of custom list view XML files.
+
+
+ <@showCheckbox "developer_pageContents_logCustomShortView" />
+ Log the use of custom short views in search, index and browse pages.
+
+
+
+
+ Language support
+
+ <@showCheckbox "developer_i18n_defeatCache" />
+ Defeat the cache of language property files
+
+
+ <@showCheckbox "developer_i18n_logStringRequests" />
+ Log the retrieval of language strings
+
+
+
+
+
+
+
+ Freemarker templates
+
+ <@showCheckbox "developer_defeatFreemarkerCache" />
+ Defeat the template cache
+
+
+ <@showCheckbox "developer_insertFreemarkerDelimiters" />
+ Insert HTML comments at start and end of templates
+
+
+
+
+ SPARQL Queries
+
+ <@showCheckbox "developer_loggingRDFService_enable" />
+ Log each query
+
+
+
+ <@showCheckbox "developer_loggingRDFService_stackTrace" />
+ Add stack trace
+
+
+ Restrict by query string
+ <@showTextbox "developer_loggingRDFService_queryRestriction" />
+
+
+ Restrict by calling stack
+ <@showTextbox "developer_loggingRDFService_stackRestriction" />
+
+
+
+
+
+
+
+ Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.
+ Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.
diff --git a/webapp/web/js/developer/developerPanel.js b/webapp/web/js/developer/developerPanel.js
index 9f8cabff8..bd7e35c40 100644
--- a/webapp/web/js/developer/developerPanel.js
+++ b/webapp/web/js/developer/developerPanel.js
@@ -14,6 +14,7 @@ function DeveloperPanel(developerAjaxUrl) {
enablePanelOpener();
addBehaviorToElements();
updateDisabledFields();
+ initializeTabs();
}
}
});
@@ -55,6 +56,10 @@ function DeveloperPanel(developerAjaxUrl) {
document.getElementById("developer_loggingRDFService_stackRestriction").disabled = !rdfServiceEnabled;
}
+ function initializeTabs() {
+ $("#developerTabs").tabs();
+ }
+
function collectFormData() {
var data = new Object();
getCheckbox("developer_enabled", data);
@@ -82,9 +87,14 @@ function DeveloperPanel(developerAjaxUrl) {
}
/*
* Relies on the global variable for the AJAX URL.
*/
$(document).ready(function() {
+ $.each(developerCssLinks, function(index, value){
+ var cssLink = $(" ");
+ $("head").append(cssLink);
+ });
+
new DeveloperPanel(developerAjaxUrl).setupDeveloperPanel({});
});
@@ -82,9 +87,14 @@ function DeveloperPanel(developerAjaxUrl) {
}
/*
- * Relies on the global variable for the AJAX URL.
+ * Relies on the global variables for the AJAX URL and the CSS files.
*/
$(document).ready(function() {